# Wiiki-Editor
A Python package containing useful functions and classes for editing the [Custom Mario Kart Wiiki](https://wiki.tockdom.com/wiki/Main_Page).

## Installation
Run `pip install wiiki-editor` in a console to install the package from [PyPi](https://pypi.org).

### Requirements
A (bot) account with a password and API key on the Custom Mario Kart Wiiki.
